@@ -148,6 +148,20 @@ def get_client(project_id=None, credentials=None,
     return BigQueryClient(bq_service, project_id, swallow_results)
 
 
+def get_projects(bq_service):
+    """Given the BigQuery service, return data about all projects."""
+    projects_request = bq_service.projects().list().execute()
+
+    projects = []
+    for project in projects_request.get('projects', []):
+        project_data = {
+            'id': project['id'],
+            'name': project['friendlyName']
+        }
+        projects.append(project_data)
+    return projects
+
+
 def _get_bq_service(credentials=None, service_url=None):
     """Construct an authorized BigQuery service object."""
 
@@ -262,7 +276,7 @@ class BigQueryClient(object):
             body=body_object
         ).execute()
 
-    def query(self, query, max_results=None, timeout=0, dry_run=False):
+    def query(self, query, max_results=None, timeout=0, dry_run=False, use_legacy_sql=None):
         """Submit a query to BigQuery.
 
         Parameters
@@ -278,6 +292,9 @@ class BigQueryClient(object):
             If True, the query isn't actually run. A valid query will return an
             empty response, while an invalid one will return the same error
             message it would if it wasn't a dry run.
+        use_legacy_sql : bool, optional. Default True.
+            If False, the query will use BigQuery's standard SQL (https://cloud.google.com/bigquery/sql-reference/)
+
 
         Returns
         -------
@@ -298,8 +315,12 @@ class BigQueryClient(object):
             'query': query,
             'timeoutMs': timeout * 1000,
             'dryRun': dry_run,
-            'maxResults': max_results,
+            'maxResults': max_results
         }
+
+        if use_legacy_sql is not None:
+            query_data['useLegacySql'] = use_legacy_sql
+
         return self._submit_query_job(query_data)
 
     def get_query_schema(self, job_id):
@@ -1027,6 +1048,9 @@ class BigQueryClient(object):
             priority=None,
             create_disposition=None,
             write_disposition=None,
+            use_legacy_sql=None,
+            maximum_billing_tier=None,
+            flatten=None
     ):
         """
         Write query result to table. If dataset or table is not provided,
@@ -1055,6 +1079,18 @@ class BigQueryClient(object):
             One of the JOB_CREATE_* constants
         write_disposition : str, optional
             One of the JOB_WRITE_* constants
+        use_legacy_sql: bool, optional
+            If False, the query will use BigQuery's standard SQL
+            (https://cloud.google.com/bigquery/sql-reference/)
+        maximum_billing_tier : integer, optional
+            Limits the billing tier for this job. Queries that have resource
+            usage beyond this tier will fail (without incurring a charge). If
+            unspecified, this will be set to your project default. For more
+            information,
+            see https://cloud.google.com/bigquery/pricing#high-compute
+        flatten : bool, optional
+            Whether or not to flatten nested and repeated fields
+            in query results
 
         Returns
         -------
@@ -1081,9 +1117,18 @@ class BigQueryClient(object):
         if allow_large_results is not None:
             configuration['allowLargeResults'] = allow_large_results
 
+        if flatten is not None:
+            configuration['flattenResults'] = flatten
+
+        if maximum_billing_tier is not None:
+            configuration['maximumBillingTier'] = maximum_billing_tier
+
         if use_query_cache is not None:
             configuration['useQueryCache'] = use_query_cache
 
+        if use_legacy_sql is not None:
+            configuration['useLegacySql'] = use_legacy_sql
+
         if priority:
             configuration['priority'] = priority
 
